@@ -78,20 +78,27 @@ class neigh(torch.nn.Module):
         self.args = args
         self.out_channels = out_channels       
         self.conv1 = Dense_SAGEConv(in_channels, in_channels,paramApply)
-        self.conv2 = Dense_SAGEConv(in_channels, in_channels,paramApply)
-        self.conv3 = Dense_SAGEConv(in_channels, out_channels,paramApply)
+        if args['n_hops_neighborhoods']>1:
+            self.conv2 = Dense_SAGEConv(in_channels, in_channels,paramApply)
+        if args['n_hops_neighborhoods']>2:
+            self.conv3 = Dense_SAGEConv(in_channels, out_channels,paramApply)
        
     def reset_parameters(self):
         # First MLP into the features
         self.conv1.reset_parameters()
-        self.conv2.reset_parameters()
-        self.conv3.reset_parameters()
+        if self.args['n_hops_neighborhoods']>1:
+            self.conv2.reset_parameters()
+        if self.args['n_hops_neighborhoods']>2:
+            self.conv3.reset_parameters()
 
     def forward(self, x, edge_index, device, num_nodes,args):        
         x = F.dropout(x, p=args['dropoutRate'], training=self.training)
         x = self.conv1(x, edge_index, device, num_nodes)
-        x = self.conv2(x, edge_index, device, num_nodes)
-        x = self.conv3(x, edge_index, device, num_nodes)  
+        
+        if self.args['n_hops_neighborhoods']>1:
+            x = self.conv2(x, edge_index, device, num_nodes)
+        if self.args['n_hops_neighborhoods']>2:
+            x = self.conv3(x, edge_index, device, num_nodes)  
 
         # Calculate mean and std
         self.mean, self.std = batchNorm(x,num_nodes,device)
