@@ -91,7 +91,7 @@ class NaroNet_model_simple(torch.nn.Module):
         self.s.append(self.area_clust(data.x, data.edge_index, device, data.num_nodes,args))                            
         
         # Obtain Cell Entropy Loss
-        contrast_loss_Ar, PatchEntropy_loss_Ar = loss.patch_contrast_entropy(self.area_emb(data.x, data.edge_index, device, data.num_nodes,args),F.softmax(self.s[-1],dim=2), [self.s[-1].shape[1]]*self.s[-1].shape[0],device)
+        contrast_loss_Ar, PatchEntropy_loss_Ar = loss.patch_contrast_entropy(self.area_emb(data.x, data.edge_index, device, data.num_nodes,args),F.softmax(self.s[-1],dim=2), [self.s[-1].shape[1]]*self.s[-1].shape[0],device,args)
 
         # Apply Softmax to cluster assignment             
         self.s[-1] = self.softmaxToClst(self.s[-1],args,device)
@@ -107,7 +107,7 @@ class NaroNet_model_simple(torch.nn.Module):
         self.s.append(self.neigh_clust(data.x, data.edge_index, device, data.num_nodes,args))  
 
         # Obtain patch
-        contrast_loss_Nb, PatchEntropy_loss_Nb = loss.patch_contrast_entropy(self.neigh_emb(data.x, data.edge_index, device, data.num_nodes,args),F.softmax(self.s[-1],dim=2), data.num_nodes,device)
+        contrast_loss_Nb, PatchEntropy_loss_Nb = loss.patch_contrast_entropy(self.neigh_emb(data.x, data.edge_index, device, data.num_nodes,args),F.softmax(self.s[-1],dim=2), data.num_nodes,device,args)
                 
         # Apply Softmax to cluster assignment       
         self.s[-1] = self.softmaxToClst(self.s[-1],args,device)
@@ -127,7 +127,7 @@ class NaroNet_model_simple(torch.nn.Module):
         self.s = self.ObtainPhenotypesClustering(data.x,data, device, args)                                          
 
         # Calculate patch entropy and contrast loss
-        contrast_loss_Ph, PatchEntropy_loss_Ph = loss.patch_contrast_entropy(data.x,F.softmax(self.s[0],dim=2), data.num_nodes,device)
+        contrast_loss_Ph, PatchEntropy_loss_Ph = loss.patch_contrast_entropy(data.x,F.softmax(self.s[0],dim=2), data.num_nodes,device,args)
                         
         # Apply Softmax to cluster assignment
         self.s[-1] = self.softmaxToClst(self.s[-1],args,device)        
