@@ -71,7 +71,7 @@ def visualize_batch_effect_Ph(out_dir,features,features_idx,count):
     features = features[sel_subjects]
     
     # Select number of patches
-    num_val = min(100000,features_idx.shape[0]*0.75)
+    num_val = min(100000,features_idx.shape[0]*0.9)
     features_idx = features_idx[::int(features_idx.shape[0]/num_val)]
     features = features[::int(features.shape[0]/num_val),:]
 
@@ -84,12 +84,12 @@ def visualize_batch_effect_Ph(out_dir,features,features_idx,count):
     scaled_features = StandardScaler().fit_transform(features[:,2:])
 
     # Create UMAP
-    embedding = TSNE().fit(scaled_features)
+    embedding = TSNE(n_jobs=8,random_state=3, verbose=True).fit(scaled_features)
 
     # Create and save scatter plot figure
-    plt.close()
+    plt.close('all')
     fig, ax = plt.subplots()   
-    scatter = ax.scatter(embedding[:, 0],embedding[:, 1],s=2,c=features_idx,cmap="gist_rainbow")
+    scatter = ax.scatter(embedding[:, 0],embedding[:, 1],s=0.5,c=features_idx,cmap='jet',edgecolors='none')
     legend1 = ax.legend(*scatter.legend_elements(),loc="upper right", title="Subjects")
     ax.add_artist(legend1)
     plt.title('TSNE of the dataset - one pat', fontsize=24)    
@@ -159,6 +159,7 @@ class SimCLR(object):
         logging.info(f"Start SimCLR training for {self.args['PCL_Epochs']} epochs.")        
 
         for epoch_counter in tqdm(range(self.args['PCL_Epochs']),initial=int(done_epochs)):
+            epoch_counter += int(done_epochs) 
             for images in train_loader:
                 images[0] = torch.cat(torch.tensor_split(images[0], images[0].shape[0]),1).squeeze()
                 images[1] = torch.cat(torch.tensor_split(images[1], images[1].shape[0]),1).squeeze()
@@ -199,7 +200,7 @@ class SimCLR(object):
                 logging.debug(f"Epoch: {epoch_counter}\tLoss: {loss}\tTop1 accuracy: {top1[0]}\tTop5 accuracy: {top5[0]}")
 
             # warmup for the first 10 epochs
-            if epoch_counter >= 6*(self.args['PCL_Epochs']/10):
+            if epoch_counter >= 11*(self.args['PCL_Epochs']/10):
                 self.scheduler.step()
             
             # save model checkpoints
@@ -208,6 +209,9 @@ class SimCLR(object):
                 torch.save(self.model.state_dict(), os.path.join(self.model_dir, checkpoint_name))        
                 logging.info(f"Model checkpoint and metadata has been saved at {self.model_dir}.")
 
+            if epoch_counter>=self.args['PCL_Epochs']:
+                break
+
         logging.info("Training has finished.")
         
 
@@ -233,7 +237,7 @@ class SimCLR(object):
             self.model = self.model.to(self.args['PCL_GPU_INDEX'])
             
             # Minibatch to extract features
-            step = 400
+            step = self.args['PCL_N_Crops_per_Image']*self.args['PCL_Batch_Size']
             features = []
             for p in range(0,len(patches),step):                
                 features.append(self.model(torch.moveaxis(torch.squeeze(torch.tensor(np.stack(patches[p:p+step],0),device=self.args['PCL_GPU_INDEX'])),3,1).to(torch.float32)).to('cpu').detach().numpy())
@@ -314,49 +318,6 @@ class SimCLR(object):
         visualize_batch_effect_Ph(out_dir,features,features_idx,0)
 
         # Cluster image 
-        visualize_using_clustering_ALL(self, out_dir, features, features_idx, patch_images)
-
-
-
-            # # Save features
-            # features = np.concatenate((np.squeeze(patch_pos),features),axis=1)    
-
-            # # Join several images to one numpy structure
-            # patient_to_image = [i for i in os.listdir(self.args['path']+'Raw_Data/Experiment_Information/') if 'Patient_to_Image.xlsx'==i]
-            # if len(patient_to_image)>0:
-                
-            #     # Find subject name and subject file
-            #     patient_to_image_excel = pd.read_excel(self.args['path']+'Raw_Data/Experiment_Information/'+patient_to_image[0])
-            #     index = list(patient_to_image_excel['Image_Name']).index(filename[0])
-            #     NPYname = self.folder+patient_to_image_excel['Subject_Name'][index]+'.npy'
-                
-            #     # if already exists...                 
-            #     if os.path.isfile(NPYname):
-                    
-            #         # Load previous concatenate with actual data and save it.
-            #         prevFeats = np.load(NPYname)
-            #         features[:,:2] = features[:,:2] + prevFeats[:,:2].max() + self.args['PCL_Patch_Size']*10 
-            #         np.save(NPYname,np.concatenate((prevFeats,features),axis=0))      
-            #         del prevFeats           
-
-            #     else:
-
-            #         # Create new file
-            #         np.save(NPYname,features)    
-                
-            # # Save one image is one subject
-            # else:
-            #     np.save(self.folder+filename[0],features)    
-            #     # tifffile.imsave(self.folder+filename[0]+'##.tiff',np.stack([np.reshape(features[:,i],(289,240)) for i in range(features.shape[1])]))
-
-
-            # # Eliminate data from garbage collector
-            # del patches, patch_pos, filename, features 
-            # gc.collect(0)
-            # gc.collect(1)      
-            # gc.collect(2)      
-            
-            
-            # visualize_using_clustering(folder+filename[0],features,[1200,1200],patches.shape[2],image)
+        # visualize_using_clustering_ALL(self, out_dir, features, features_idx, patch_images)    
 
         return 
\ No newline at end of file
