@@ -163,11 +163,11 @@ def gather_apply_loss(training, contrast_loss_Ph, PatchEntropy_loss_Ph, contrast
     loss  = contrast_loss_Ph*args['ContrastACC_Pheno'] + PatchEntropy_loss_Ph*args['PatchEntropy_Pheno']
     loss += contrast_loss_Nb*args['ContrastACC_Neigh'] + PatchEntropy_loss_Nb*args['PatchEntropy_Neigh'] 
     loss += contrast_loss_Ar*args['ContrastACC_Area']  + PatchEntropy_loss_Ar*args['PatchEntropy_Area'] 
-    # loss += Cross_entropy_loss 
+    loss += Cross_entropy_loss 
     
     if training:
         loss.backward()    
-        print(model.pheno_clust.lin.weight.grad)
+        # print(model.pheno_clust.lin.weight.grad)
         optimizer.step() 
         optimizer.zero_grad()
     
